print the details of an object of class summary.DImulti
# S3 method for summary.DImulti
print(x, verbose = FALSE, digits = .Options$digits, ...)object x
an object of class DImulti
an optional logical value used to control the amount of output when the object is printed. Defaults to FALSE.
the number of significant digits to use when printing
some methods for this generic function require additional arguments. None are used in this method.
print which this function wraps.