Learn R Programming

DImodelsMulti (version 1.2.1)

Belgium_RM: The repeated measures Belgium dataset

Description

Single site dataset containing thirty experimental units (plots), with four species seeded at two density levels, representing fifteen communities. A single ecosystem function response is recorded for each plot over three years. The responses have been linearly transformed to lie on a percentage scale. Data is in a stacked format.

Usage

data("Belgium_RM")

Arguments

Format

A data frame with 150 observations on the following 9 variables.

YEARN

a numeric vector indicating the time point (year) that the ecosystem function recording was measured at

PLOT

a numeric vector indicating the ID of the experimental unit from which the observation was recorded

G1

a numeric vector ranging from 0 to 1, the proportion of the species G1

G2

a numeric vector ranging from 0 to 1, the proportion of the species G2

L1

a numeric vector ranging from 0 to 1, the proportion of the species L1

L2

a numeric vector ranging from 0 to 1, the proportion of the species L2

DENS

a vector of factors with two levels, -1 or 1, representing the seeding density of the plot

Var

a character vector indicating the ecosystem function recorded

Y

a numeric vector indicating the value of the ecosystem function recorded

Details

Data comes from a single site from a wider agrodiversity experiment conducted in Belgium, established in 2002.
The four species used were Lolium perenne (G1), Phleum pratense (G2), Trifolium pratense (L1), and Trifolium repens (L2). There are two recommended functional groupings: grouping grasses (G1, G2) and legumes (L1, L2), or grouping fast-establishing species (G1, L1) and temporally persistent species (G2, L2).
The ecosystem function (aboveground biomass of sown species (Sown) (t DM ha-1)) were recorded by summing recordings from multiple harvests over the years of of the experiment. A linear transformation on the response was applied to the value 'Y', where it now represents a percentage of the top 10% of recorded values, i.e., each response was multiplied by 100, then divided by the mean of the top nine readings.
This dataset was extracted from the dataset 'Belgium'.

References

Dooley, A., Isbell, F., Kirwan, L., Connolly, J., Finn, J.A. and Brophy, C., 2015.
Testing the effects of diversity on ecosystem multifunctionality using a multivariate model.
Ecology Letters, 18(11), pp.1242-1251.

Kirwan, L., Connolly, J., Brophy, C., Baadshaug, O.H., Belanger, G., Black, A., Carnus, T., Collins, R.P., Cop, J., Delgado, I., De Vliegher, A., Elgersma A., Frankow-Lindberg, B., Golinski, P., Grieu, P., Gustavsson, A.M., Helgadóttir, Á., Höglind, M., Huguenin-Elie, O., Jørgensen, M., Kadžiulienė, Ž., Lunnan, T., Lüscher, A., Kurki, P., Porqueddu, C., Sebastia, M.-T., Thumm, U., Walmsley, D., and Finn, J., 2014.
The Agrodiversity Experiment: three years of data from a multisite study in intensively managed grasslands.

Finn, J.A., Kirwan, L., Connolly, J., Sebastia, M.T., Helgadottir, A., Baadshaug, O.H., Belanger, G., Black, A., Brophy, C., Collins, R.P., Cop, J., Dalmannsdóttir, S., Delgado, I., Elgersma, A., Fothergill, M., Frankow-Lindberg, B.E., Ghesquiere, A., Golinska, B., Golinski, P., Grieu, P., Gustavsson, A.M., Höglind, M., Huguenin-Elie, O., Jørgensen, M., Kadziuliene, Z., Kurki, P., Llurba, R., Lunnan, T., Porqueddu, C., Suter, M., Thumm, U., and Lüscher, A., 2013.
Ecosystem function enhanced by combining four functional types of plant species in intensively managed grassland mixtures: a 3-year continental-scale field experiment.
Journal of Applied Ecology, 50(2), pp.365-375 .

Kirwan, L., Connolly, J., Finn, J.A., Brophy, C., Luscher, A., Nyfeler, D. and Sebastia, M.T., 2009.
Diversity-interaction modeling: estimating contributions of species identities and interactions to ecosystem function.
Ecology, 90(8), pp.2032-2038.

Examples

Run this code
#How to extra and transform the data from the 'Belgium' dataset

## Libraries ################################################
library(reshape2)
library(dplyr)
library(DImodelsMulti)
#############################################################
## Read in data##################################
data("Belgium")
#############################################################
## Standardise responses for Analysis 1 (RM) #################
Belgium_RM <- Belgium
#Top 9 values
top <- Belgium_RM %>%
  arrange(desc(Y)) %>%
  group_by(Var) %>%
  slice(1:9)
#Average of top values
top <- aggregate(Y ~ Var, data = top, FUN = "mean")

Belgium_RM$Y <- 100*Belgium_RM$Y

#Sown
condition <- which(Belgium_RM$Var == "Sown")
Belgium_RM$Y[condition] <- Belgium_RM$Y[condition] /
  top[1, "Y"]

#Subset to just the Sown response
Belgium_RM <- Belgium_RM[which(Belgium_RM$Var == "Sown"), ]


Belgium_RM

Run the code above in your browser using DataLab